==> cxf-testutils-2.0.10.1-fuse-sources.jar: org/apache/type_test/xml/TestBase64BinaryRestriction.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for testBase64BinaryRestriction element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testBase64BinaryRestriction">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}Base64BinaryRestriction"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}Base64BinaryRestriction"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testBase64BinaryRestriction")
public class TestBase64BinaryRestriction {

    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected byte[] x;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected byte[] y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setX(byte[] value) {
        this.x = ((byte[]) value);
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setY(byte[] value) {
        this.y = ((byte[]) value);
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/xml/TestBase64BinaryRestriction.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}Base64BinaryRestriction"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}Base64BinaryRestriction"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testBase64BinaryRestriction")
public class TestBase64BinaryRestriction {

    @XmlElement(required = true)
    protected byte[] x;
    @XmlElement(required = true)
    protected byte[] y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setX(byte[] value) {
        this.x = ((byte[]) value);
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setY(byte[] value) {
        this.y = ((byte[]) value);
    }

}
